# Youtube Studio

Unofficial Async YouTube Studio API. Set of features limited or not provided by official YouTube API!

> This is the Python version of [this project](https://github.com/adasq/youtube-studio). All thanks going to [@adasq](https://github.com/adasq) :)

## Installation

You can install with PIP.

`pip install ytstudio`

## Features

- Async
- Uploading Video (**NOT LIMITED** - official API's videos.insert charges you 1600 quota units)
- Deleting Video
- Edit Video

## Examples

**Note:** You need cookies. Use an cookie manager([EditThisCookie](https://chrome.google.com/webstore/detail/editthiscookie/fngmhnnpilhplaeedifhccceomclgfbg?hl=tr)) for needed cookies.

> You need SESSION_TOKEN for (upload/edit/delete) video. [How to get Session Token?](https://github.com/adasq/youtube-studio#preparing-authentication)

## TO-DO

- [ ] Better Documentation
- [ ] Better Tests
- [ ] More Functions

## Author

Yusuf Usta, yusuf@usta.email

## Note

This library is in no way affiliated with YouTube or Google. Use at your own discretion. Do not spam with this.
